@@ -14,29 +14,37 @@ from werkzeug.wrappers import Request
 class RestApplication(object):
     """Base REST application."""
 
-    def __init__(self, services=None, request_hooks=None, response_hooks=None):
+    def __init__(self, services, request_hooks=None, response_hooks=None):
 
         self.services = services or []
 
-        # Build a list of url endpoints from the service interfaces.
-        url_map = []
-        converters = {}
-        for service in services:
-            url_map += (service.urls
-                        if hasattr(service, 'urls')
-                        else service['urls'])
+        # If the first argument is already a werkzeug `Map` then use it.
+        if isinstance(services, Map):
 
-            # Check for custom converters used by an application.
-            custom_converters = {}
-            if hasattr(service, 'converters'):
-                custom_converters = service.converters
-            elif isinstance(service, dict) and 'converters' in service:
-                custom_converters = service['converters']
+            self.url_map = services
 
-            converters = dict(chain(converters.iteritems(),
-                                    custom_converters.iteritems()))
+        # Other wise, build a map from an iterable of `Rule` objects.
+        else:
 
-        self.url_map = Map(url_map, converters=converters)
+            # Build a list of url endpoints from the service interfaces.
+            url_map = []
+            converters = {}
+            for service in services:
+                url_map += (service.urls
+                            if hasattr(service, 'urls')
+                            else service['urls'])
+
+                # Check for custom converters used by an application.
+                custom_converters = {}
+                if hasattr(service, 'converters'):
+                    custom_converters = service.converters
+                elif isinstance(service, dict) and 'converters' in service:
+                    custom_converters = service['converters']
+
+                converters = dict(chain(converters.iteritems(),
+                                        custom_converters.iteritems()))
+
+            self.url_map = Map(url_map, converters=converters)
 
         self.request_hooks = request_hooks or []
         self.response_hooks = response_hooks or []
